local releases = {
	{
		id = "c4c396a429f8a5b31b4d703d912630ae",
		name = "Gold Road Dragoon Style",
		type = "style",
		startDate = 1718892000,
		endDate = 1719928800,
		source = "Matching armor pages will drop from Zenithar's Sublime Parcel, obtainable once per day for the duration of the event.\
\
Bound versions of the armor pages can be purchased from the Impresario for 5 Event Tickets each during the event.",
	},
	{
		id = "18df619754737bd63d7423d96dd38cb2",
		name = "Statuette: Peryite, Blightlord",
		type = "esoPlusFreebie",
		startDate = 1719496800,
		endDate = 1722261600,
	},
	{
		id = "b8e062d07f699fc8a434bfb834c01435",
		name = "Balorgh Style",
		type = "style",
		startDate = 1719842400,
		endDate = 1720447200,
		source = "The matching mask page will have a small chance to drop from Balorgh from veteran March of Sacrifices.\
\
The matching shoulder page can be purchased from Urgarlag Chief-bane for 50 Undaunted keys, or has a chance of dropping from Urgarlag's Mystery Coffer for 1 key.\
\
Having the achievement \"Hircine's Champion\" increases the drop chances of both items.",
	},
	{
		id = "2f74b4ccec46b741e0cf688d526a1481",
		name = "The Blind Style",
		type = "style",
		startDate = 1720015200,
		endDate = 1721916000,
		source = "The matching mask page will have a small chance to drop from The Blind from veteran Bedlam Veil.\
\
The matching shoulder page can be purchased from Urgarlag Chief-bane for 50 Undaunted keys, or has a chance of dropping from Urgarlag's Mystery Coffer for 1 key.\
\
Having the achievement \"Lithe and Clever\" increases the drop chances of both items.",
	},
	{
		id = "8ab9fae2381269e7b502048f5b68cac7",
		name = "Ebonsteel Knight Style",
		type = "style",
		startDate = 1720706400,
		endDate = 1721916000,
		source = "Matching armor pages will have a small chance to drop from the Bag of Veteran's Glory during Whitestrake's Mayhem.\
\
Bound versions of the armor pages can be purchased from the Impresario for 5 Event Tickets each during the event.",
	},
	{
		id = "6f45ac80ababb426b069fe4c992f5ba9",
		name = "Vykosa Style",
		type = "style",
		startDate = 1721052000,
		endDate = 1721656800,
		source = "The matching mask page will have a small chance to drop from Vykosa the Ascendant from veteran Moon Hunter Keep.\
\
The matching shoulder page can be purchased from Urgarlag Chief-bane for 50 Undaunted keys, or has a chance of dropping from Urgarlag's Mystery Coffer for 1 key.\
\
Having the achievement \"The Alpha Predator\" increases the drop chances of both items.",
	},
	{
		id = "c69772342bae9995db7fb6f5603c6bb7",
		name = "Stormfist Style",
		type = "style",
		startDate = 1721656800,
		endDate = 1721916000,
		source = "The matching mask page will have a small chance to drop from Stormreeve Neidir from veteran Tempest Island.\
\
The matching shoulder page can be purchased from Glirion the Redbeard for 50 Undaunted keys, or has a chance of dropping from Glirion's Mystery Coffer for 1 key.\
\
Having the achievement \"Burial at Sea\" increases the drop chances of both items.",
	},
	{
		id = "a4f7834e17821e1176620e2cf80de028",
		name = "Ayleid Lich Style",
		type = "style",
		startDate = 1721916000,
		endDate = 1722952800,
		source = "Matching armor pages will have a small chance to drop from Pelinal's Boon Box.\
\
Bound versions of the armor pages can be purchased from the Impresario for 5 Event Tickets each during the event.",
	},
	{
		id = "58405cc5e04d4746eceb6be58469a527",
		name = "Statuette: Auriel of Garlas Agea",
		type = "esoPlusFreebie",
		startDate = 1722261600,
		endDate = 1724940000,
	},
}

local provider = LibNotification:CreateProvider()
local declined

local function UpdateNotifications()
	local function OnDecline(data)
		declined[data.id] = true
		UpdateNotifications()
	end

	local currentTimeStamp = GetTimeStamp()
	provider.notifications = {}

	for _, v in ipairs(releases) do
		if
			(v.type ~= "esoPlusFreebie" or IsESOPlusSubscriber()) and
			declined[v.id] == nil and
			GetDiffBetweenTimeStamps(v.startDate, currentTimeStamp) <= 0 and
			(v.endDate == nil or GetDiffBetweenTimeStamps(currentTimeStamp, v.endDate) < 0)
		then
			table.insert(
				provider.notifications,
				{
					id = v.id,
					dataType = NOTIFICATIONS_ALERT_DATA,
					secsSinceRequest = ZO_NormalizeSecondsSince(0),
					note = v.type == "esoPlusFreebie" and "Free in Crown Store with ESO+" or v.source,
					message = v.name,
					heading = "Content Releases",
					shortDisplayText = "Content Releases",
					texture = v.type == "esoPlusFreebie" and "/esoui/art/treeicons/gamepad/tutorial_idexicon_esoplus.dds" or "/esoui/art/dailyloginrewards/dailyloginrewards_claimed_stamp.dds",
					keyboardDeclineCallback = OnDecline,
					gamepadDeclineCallback = OnDecline
				}
			)
		end
	end

	provider:UpdateNotifications()
end

SLASH_COMMANDS["/releases"] = function()
	local currentTimeStamp = GetTimeStamp()

	CHAT_ROUTER:AddSystemMessage("Content Releases")

	for _, v in ipairs(releases) do
		if
			(v.type ~= "esoPlusFreebie" or IsESOPlusSubscriber()) and
			(v.endDate == nil or GetDiffBetweenTimeStamps(currentTimeStamp, v.endDate) < 0)
		then
			if v.source then
				local achievementName = string.match(v.source, "achievement \"(.+)\"")

				if achievementName then
					for achievementId = 1, 9999 do
						if achievementName == GetAchievementName(achievementId) then
							v.source = string.gsub(v.source, string.gsub(achievementName, "-", "%%-"), GetAchievementLink(achievementId))
							break
						end
					end
				end
			end

			CHAT_ROUTER:AddSystemMessage(
				zo_strformat(
					v.endDate == nil and "<<1>> [<<3>>]\n<<2>>" or "<<1>> [<<3>> to <<4>>]\n<<2>>",
					v.name,
					v.type == "esoPlusFreebie" and "Free in Crown Store with ESO+" or v.source,
					GetDateStringFromTimestamp(v.startDate),
					GetDateStringFromTimestamp(v.endDate)
				)
			)
		end
	end
end

EVENT_MANAGER:RegisterForEvent(
	"ReleaseTracker",
	EVENT_ADD_ON_LOADED,
	function(_, addOnName)
		if "ReleaseTracker" ~= addOnName then return end

		declined = ZO_SavedVars:NewAccountWide("ReleaseTracker", 1, nil, {})

		UpdateNotifications()

		local currentTimeStamp = GetTimeStamp()

		for _, v in ipairs(releases) do
			local timeUntilStart = GetDiffBetweenTimeStamps(v.startDate, currentTimeStamp)

			if timeUntilStart > 0 then
				EVENT_MANAGER:RegisterForUpdate(
					"ReleaseCheck" .. v.startDate,
					timeUntilStart * 1000,
					function()
						EVENT_MANAGER:UnregisterForUpdate("ReleaseCheck" .. v.startDate)
						UpdateNotifications()
					end
				)
			end
		end
	end
)